==> orthanc_1.7.3+dfsg.orig.tar.xz: Orthanc-1.7.3/OrthancServer/Sources/ServerJobs/CleaningInstancesJob.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2020 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../../../OrthancFramework/Sources/JobsEngine/SetOfInstancesJob.h"

namespace Orthanc
{
  class ServerContext;
  
  class CleaningInstancesJob : public SetOfInstancesJob
  {
  private:
    ServerContext&  context_;
    bool            keepSource_;
    
  protected:
    virtual bool HandleTrailingStep();
    
  public:
    CleaningInstancesJob(ServerContext& context,
                         bool keepSource) :
      context_(context),
      keepSource_(keepSource)
    {
    }

    CleaningInstancesJob(ServerContext& context,
                         const Json::Value& serialized,
                         bool defaultKeepSource);

    ServerContext& GetContext() const
    {
      return context_;
    }
    
    bool IsKeepSource() const
    {
      return keepSource_;
    }
    
    void SetKeepSource(bool keep);

    virtual bool Serialize(Json::Value& target);

    virtual void Start();
  };
}

==> orthanc_1.10.1+dfsg.orig.tar.xz: Orthanc-1.10.1/OrthancServer/Sources/ServerJobs/CleaningInstancesJob.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2022 Osimis S.A., Belgium
 * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../../../OrthancFramework/Sources/JobsEngine/SetOfInstancesJob.h"

namespace Orthanc
{
  class ServerContext;
  
  class CleaningInstancesJob : public SetOfInstancesJob
  {
  private:
    ServerContext&  context_;
    bool            keepSource_;
    
  protected:
    virtual bool HandleTrailingStep() ORTHANC_OVERRIDE;
    
  public:
    CleaningInstancesJob(ServerContext& context,
                         bool keepSource) :
      context_(context),
      keepSource_(keepSource)
    {
    }

    CleaningInstancesJob(ServerContext& context,
                         const Json::Value& serialized,
                         bool defaultKeepSource);

    ServerContext& GetContext() const
    {
      return context_;
    }
    
    bool IsKeepSource() const
    {
      return keepSource_;
    }
    
    void SetKeepSource(bool keep);

    virtual bool Serialize(Json::Value& target) ORTHANC_OVERRIDE;

    virtual void Start() ORTHANC_OVERRIDE;
  };
}
